aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/de/hysky/skyblocker/utils
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/de/hysky/skyblocker/utils')
-rw-r--r--src/main/java/de/hysky/skyblocker/utils/Utils.java14
1 files changed, 13 insertions, 1 deletions
diff --git a/src/main/java/de/hysky/skyblocker/utils/Utils.java b/src/main/java/de/hysky/skyblocker/utils/Utils.java
index bbfd1101..f09d16ed 100644
--- a/src/main/java/de/hysky/skyblocker/utils/Utils.java
+++ b/src/main/java/de/hysky/skyblocker/utils/Utils.java
@@ -44,6 +44,8 @@ public class Utils {
@NotNull
private static String profile = "";
@NotNull
+ private static String profileId = "";
+ @NotNull
private static String server = "";
@NotNull
private static String gameType = "";
@@ -89,6 +91,11 @@ public class Utils {
return profile;
}
+ @NotNull
+ public static String getProfileId() {
+ return profileId;
+ }
+
/**
* @return the server parsed from /locraw.
*/
@@ -323,7 +330,7 @@ public class Utils {
}
/**
* Parses the /locraw reply from the server
*
* @return not display the message in chat is the command is sent by the mod
*/
@@ -349,6 +356,11 @@ public class Utils {
return shouldFilter;
}
}
+
+ if (isOnSkyblock && message.startsWith("Profile ID: ")) {
+ profileId = message.replace("Profile ID: ", "");
+ }
+
return true;
}
@@ -323,7 +330,7 @@ public class Utils {
}
/**
- * Parses the /locraw reply from the server
+ * Parses the /locraw reply from the server and updates the player's profile id
*
* @return not display the message in chat is the command is sent by the mod